#!/bin/sh
#
# bb-swap.sh - BB extension script to monitor swap space.
#
# Nick Metrowsky
# nmetro@colorado.edu
# University of Colorado (JILA)
# 22 May, 2001
#
# Version: 1.10
#
######################################################################################
#   
# This program is not part of the original Big Brother Distribution, but is
# considered a plug-in replacement for the distributed bb-hist.sh. As author,
# I give permission for anyone to use this program to enhance their use of
# Big Brother. This program can be modified or improved, as desired. If someone
# feels that a universal change is needed (to fix a bug or add a feature), please
# post those changes to the Big Brother mailing list (bb@bb4.com). 
#
# As with the rest of Big Brother, this code cannot be sold or used for commercial gain.
#
# Copyright 1999, 2000
# The University of Colorado
# All Rights Reserved
#
######################################################################################
#
# Change History:
#
#	1.10	05/22/2001	Added support for NetBSD
#	1.9	09/20/2000	Added support for OpenBSD
#	1.8	09/11/2000	Added support for IRIX.
#	1.7	08/25/2000	Added "solaris" to "sunos" definition.
#	1.6	07/27/2000	All configurable items moved to an external script
#				Added support for Debian Linux 
#				    Replaced the use of uname for getting the OS
#				      and now uses BBOSTYPE instead, as it 
#				      was required for Debian support.
#				Added "installation" instructions
#				These changes were contributed by Christian Perrier
#				 (Christian.Perrier@onera.fr)
#	1.5	02/16/2000	Added suuport for SCO_V5 and UNIX_SV
#	1.4	12/22/1999	Added support for FreeBSD
#	1.3	12/16/1999	Added support for Dynix/ptx
#	1.2	11/19/1999	Added support for AIX
#	1.1	02/28/1999	Added Support for HP-UX
#	1.0	01/15/1999	Original Release (OSF1, SunOS & RedHat Linux)
#
######################################################################################
#
# Set up BBPROG Variable
#
BBPROG=bb-swap.sh; export BBPROG
#
# Set up Column Name for display
#
TEST="swap"
#
# BBHOME Variable is set up from runbb.sh.
#
if test "$BBHOME" = ""
then
        echo "BBHOME is not set... exiting"
        exit 1
fi
#
# The name of the configuration file
#
BBSWAPCONFIG=$BBHOME/etc/bb-swap-cfg.sh
#
# Get variables in bbdef.sh if BBTMP not setup
#
if test ! "$BBTMP"
then
         # echo "*** LOADING BBDEF ***"
        . $BBHOME/etc/bbdef.sh          # INCLUDE
fi

if [ ! -r $BBSWAPCONFIG ]
then
	echo "Configuration file $BBSWAPCONFIG not found... exiting"
	exit 1
else
	# echo "*** LOADING $BBSWAPCONFIG ***"
	. $BBSWAPCONFIG
fi

#=====================================================================
# NOTIFY ON SWAP SPACE UTILIZATION
#=====================================================================
#
# echo "*** SWAP SPACE TEST ***"

COLOR="green"

case "$BBOSTYPE"
in
	aix)		# For AIX [from Tom Kauffman (kauffmanT@nibco.com) 11/19/1999]
		used=`/usr/sbin/lsps -s | $GREP "%" | $AWK '{ print $2 }' |  cut -d% -f1`
		SWAPPCT=`echo "scale=2;100 - $used" | bc`
		;;
	dynix)		# For Sequent DYNIX/ptx [from Stephen Couch (couch@freemontcomp.com) 12/16/1999]
		total=`/etc/swap -l | $GREP "dsk" | $AWK '{blks=blks+$4};END{print blks}'`
		free=`/etc/swap -f | $GREP "used" | $AWK '{print $3}'`
		dec=`echo "scale=2;$free / $total * 100" | bc`
		SWAPPCT=`echo $dec|cut -d. -f1`
		;;
	freebsd)	# For FreeBSD [from Rick Owens (owens@fvcc.cc.mt.us) 12/22/1999]
		SWAPPCT=`/usr/sbin/swapinfo | /usr/bin/tail -1 | $AWK '{print 100 - $5}'`
		;;
	hp-ux)		# For HP UNIX [from Jason Armbruster (armbrust@cusys.edu) 02/28/1999]
		used=`/usr/sbin/swapinfo -t | $GREP "total" | $AWK '{ print substr($5,0,2) }'`
		SWAPPCT=`echo "scale=2;100 - $used" | bc`
		;;
	irix)		# For IRIX [from Christian Perrier (christian.perrier@onera.fr) 09/11/2000]
		avail=`/sbin/swap -lbfn | $GREP -v '^ #' | $AWK '{ print $7 }'`
		total=`/sbin/swap -lbfn | $GREP -v '^ #' | $AWK '{ print $8 }'`
		dec=`echo "scale=2;$avail / $total * 100" | bc`
		SWAPPCT=`echo $dec | cut -d. -f1`
		;;
	linux|redhat)	# For Linux
		free=`/usr/sbin/free | $GREP "Swap:" | $AWK '{ print $4 }' | cut -dk -f1`
		total=`/usr/sbin/free | $GREP "Swap:" | $AWK '{ print $2 }' | cut -dk -f1`
		dec=`echo "scale=2;$free / $total * 100" | bc`
		SWAPPCT=`echo $dec | cut -d. -f1`
		;;
	debian | mandrake)		# For Debian Linux : free lives in /usr/bin
		free=`/usr/bin/free | $GREP "Swap:" | $AWK '{ print $4 }' | cut -dk -f1`
		total=`/usr/bin/free | $GREP "Swap:" | $AWK '{ print $2 }' | cut -dk -f1`
		dec=`echo "scale=2;$free / $total * 100" | bc`
		SWAPPCT=`echo $dec | cut -d. -f1`
		;;
	openbsd|netbsd)	# For OpenBSD/netbsd [from Josh Rivel (jrivel@dti.net)
		SWAPPCT=`/sbin/swapctl -l | /usr/bin/tail -1 | $AWK '{ print 100 - $5 }'`
		;;
	osf)		# For Compaq Tru64 UNIX/Digital UNIX/ Digital OSF/1
		SWAPPCT=`/usr/sbin/swapon -s | $GREP "Available" | $AWK '{ print substr($6,0,2) }'`
		;;
	sco|unixware)	# For SCO 5 & unixware v2 [from Nicolas Chuche (nchuche@teaser.fr) 02/16/2000)
		free=`/etc/swap -l | $GREP -v path | $AWK '{ print $5 }'`
		total=`/etc/swap -l | $GREP -v path | $AWK '{ print $5 }'`
		dec=`echo "scale=2;$free / $total * 100" | bc`
		SWAPPCT=`echo $dec | cut -d. -f1`
		;;
	sunos|solaris)	# For Solaris and SunOS
		used=`/usr/sbin/swap -s | $AWK '{ print $9 }' | cut -dk -f1`
		avail=`/usr/sbin/swap -s | $AWK '{ print $11 }' | cut -dk -f1`
		total=`expr $used + $avail`
		dec=`echo "scale=2;$avail / $total * 100" | bc`
		SWAPPCT=`echo $dec | cut -d. -f1`
		;;
	*)		# For Unknown Operating Systems
		SWAPPCT=100
		;;
esac
#######################################################################
HEURE=`date +%s`
ZERO="0"
COLOR="green"


  if test  "$SWAPPCT" -le "$SWAPWARN"
  then
          DMPW="0"
  fi
  if  test  "$SWAPPCT" -le "$SWAPPANIC"
  then
	DSP="0"
   fi
   if  test -s /usr/local/BB/bb19a/etc/swapW
   then
	DSW=`cat /usr/local/BB/bb19a/etc/swapW`
   fi
   if test -s /usr/local/BB/bb19a/etc/swapP
   then
        	DSP=`cat /usr/local/BB/bb19a/etc/swapP`
   fi

  if test "$SWAPPCT" -ge "$SWAPPANIC"
  then

	if test "$DSP" -le "$ZERO"
	then
                      DSP="$HEURE"
            fi
	TEMP=$[$HEURE-$DSP]
	if test "$TEMP" -ge "$DUSP"
	then
                        COLOR="red"
	else
	        if test "$DSW" -le "$ZERO"
                    then
                       	DSW="$HEURE"
	        fi
	    TEMP=$[$HEURE-$DSW]
                    if test "$TEMP" -ge "$DUSW"
                    then
                	COLOR="yellow"
                 else
		COLOR="green"
	fi
             fi

   else

         if test "$SWAPPCT" -ge "$SWAPWARN"
         then

    	if test "$DSW" -le "$ZERO"
	then
    	     DSW="$HEURE"
            fi
          TEMP=$[$HEURE-$DSW]
          	if test "$TEMP" -ge "$DUSW"
            then
                    COLOR="yellow"
	
	else
		COLOR="green"
	fi
        else
	COLOR="green"
	fi
   fi
#on place les horaires de dpart dans un fichier afin de les sauvegarder.
echo "$DSW" > /usr/local/BB/bb19a/etc/swapW
echo "$DSP" > /usr/local/BB/bb19a/etc/swapP
#
# NOW SEND THIS INFORMATION TO THE BIG BROTHER DISPLAY UNIT
#

$BB $BBDISP "status $MACHINE.swap $COLOR `date` $SWAPPCT % Free Swap Space
heure: $HEURE
depart alerte warning $DSW
depart alerte panic $DSP  "



